<?php

use Firebase\JWT\TokenJWT;

//https://github.com/bramus/router
require_once "modelo/Router.php";
require_once "modelo/Usuario.php";
require_once "modelo/TokenJWT.php";

//Cria uma instância da classe Router
$router  = new Router();

// trata a rota: POST: /usuario, a rota cadastra um cliente.
$router->post('/usuarios', function () {
  //recupera os dados enviados no corpo da requisição.
  $jsonRecebido = file_get_contents('php://input');
  $obj = json_decode($jsonRecebido);   //converte os dados em um objeto json.
  $u1 = new Usuario();   //cria uma instância de Usuario
  //faz o "set" dos dados dentro da classe.
  $u1->setNome($obj->nome);
  $u1->setEmail($obj->email);
  $u1->setSenha($obj->senha);
  //verifica se existe algum usuário com o mesmo email
  if ($u1->usuarioExiste() == false) {
    //executa o método create da classe Usuário
    //prepara o array resposta que será convertido em json
    $resposta['status'] = $u1->create();
    $resposta['msg'] = 'cadastrado com sucesso';
    $resposta['dados'] = $u1;
  } else {
    $resposta['status'] = false;
    $resposta['msg'] = 'já existe um usuário com o e-mail fornecido';
    $resposta['dados'] = $u1;
  }
  echo json_encode($resposta);
});

// trata a rota: GET /usuario, retorna todos os usuários
$router->get('/usuarios', function () {
  //recupera o header contendo o token de autorização
  $headers     = apache_request_headers();
  //instância a classe TokenJWT()
  $tokenJWT = new TokenJWT();
  //verifica se o token é valido ou não
  if ($tokenJWT->validarToken($headers) == true) {
    $u1 = new Usuario();
    $resposta['status'] = true;
    $resposta['dados'] =  $u1->readAll();
    echo json_encode($resposta);
    exit;
  } else {
    $resposta['status'] = false;
    $resposta['msg'] =  'Token inválido';
    echo json_encode($resposta);
  }
});

//trata a rota: GET /usuario/idUsuario, retorna usuário com id especifico
$router->get('/usuarios/(\d+)', function ($v1) {
  //recupera o header contendo o token de autorização
  $headers     = apache_request_headers();
  //instância a classe TokenJWT()
  $tokenJWT = new TokenJWT();
  //verifica se o token é valido ou não
  if ($tokenJWT->validarToken($headers) == true) {
    $u1 = new Usuario();
    $u1->setIdUsuario($v1);
    $resposta['status'] = true;
    $resposta['dados'] =  $u1->read();
    echo json_encode($resposta);
  } else {
    $resposta['status'] = false;
    $resposta['msg'] =  'Token inválido';
    echo json_encode($resposta);
  }
});

//trata a rota: PUT /usuario/idUsuario
$router->put('/usuarios/(\d+)', function ($v1) {
  //recupera o header contendo o token de autorização
  $headers     = apache_request_headers();
  //instância a classe TokenJWT()
  $tokenJWT = new TokenJWT();
  //verifica se o token é valido ou não
  if ($tokenJWT->validarToken($headers) == true) {
    $u1 = new Usuario();
    //recupera os dados enviado no corpo da requisição.
    $jsonRecebido = file_get_contents('php://input');
    //converte os dados em um objeto json.
    $obj = json_decode($jsonRecebido);
    //faz o set dos dados para update
    $u1->setIdUsuario($v1);
    $u1->setNome($obj->nome);
    $u1->setEmail($obj->email);
    $u1->setSenha($obj->senha);
    $resposta['status'] = $u1->update();
    $resposta['msg'] = "Atualizado com sucesso";
    $resposta['dados'] = $u1;
    echo json_encode($resposta);
  } else {
    $resposta['status'] = false;
    $resposta['msg'] = 'Usuário não logado';
    echo json_encode($resposta);
  }
});

////trata a rota: DELETE /usuario/idUsuario
$router->delete('/usuarios/(\d+)', function ($v1) {
   //recupera o header contendo o token de autorização
   $headers     = apache_request_headers();
   //instância a classe TokenJWT()
   $tokenJWT = new TokenJWT();
   //verifica se o token é valido ou não
   if ($tokenJWT->validarToken($headers) == true) {
    $u1 = new Usuario();
    $u1->setIdUsuario($v1);
    $resposta['status'] = $u1->delete();
    $resposta['msg'] = "excluído com sucesso";
    echo json_encode($resposta);
  } else {
    $resposta['status'] = false;
    $resposta['msg'] = 'Usuário não logado';
    echo json_encode($resposta);
  }
});

//trata a rota POST: / login, verifica se usuário e senha estão corretos, cria uma sessão para o usuário
$router->post('/login', function () {
  $jsonRecebido = file_get_contents('php://input');
  $obj = json_decode($jsonRecebido);
  $u1 = new Usuario();
  $u1->setEmail($obj->email);
  $u1->setSenha($obj->senha);
  $resposta = array();
  if ($u1->verificarUsuarioSenha() == true) {
    $tokenJWT = new TokenJWT();
    $novoToken = $tokenJWT->gerarToken(json_encode($u1));
    $resposta['status'] = 'true';
    $resposta['msg'] = "Login efetuado com sucesso";
    $resposta['token'] =  $novoToken;
  }else{
    $resposta['status'] = 'false';
    $resposta['msg'] = "Login inválido";
  }
  echo json_encode($resposta);
});

$router->run();
